@@ -81,7 +81,7 @@ objoutsize = {
         'specdesc': '1',
         'tempo': '1',
         'filterbank': 'self->n_filters',
-        'tss': 'self->hop_size',
+        'tss': 'self->buf_size',
         }
 
 objinputsize = {
@@ -93,6 +93,7 @@ objinputsize = {
         'specdesc': 'self->buf_size / 2 + 1',
         'tempo': 'self->hop_size',
         'wavetable': 'self->hop_size',
+        'tss': 'self->buf_size / 2 + 1',
         }
 
 def get_name(proto):
@@ -182,17 +183,21 @@ class MappedObject(object):
 
     def gen_code(self):
         out = ""
-        out += self.gen_struct()
-        out += self.gen_doc()
-        out += self.gen_new()
-        out += self.gen_init()
-        out += self.gen_del()
-        out += self.gen_do()
-        out += self.gen_memberdef()
-        out += self.gen_set()
-        out += self.gen_get()
-        out += self.gen_methodef()
-        out += self.gen_typeobject()
+        try:
+            out += self.gen_struct()
+            out += self.gen_doc()
+            out += self.gen_new()
+            out += self.gen_init()
+            out += self.gen_del()
+            out += self.gen_do()
+            out += self.gen_memberdef()
+            out += self.gen_set()
+            out += self.gen_get()
+            out += self.gen_methodef()
+            out += self.gen_typeobject()
+        except Exception as e:
+            print ("Failed generating code for", self.shortname)
+            raise
         return out
 
     def gen_struct(self):
@@ -305,7 +310,7 @@ Py_{shortname}_init (Py_{shortname} * self, PyObject * args, PyObject * kwds)
         out += """
   // return -1 and set error string on failure
   if (self->o == NULL) {{
-    PyErr_Format (PyExc_Exception, "failed creating {shortname}");
+    PyErr_Format (PyExc_RuntimeError, "failed creating {shortname}");
     return -1;
   }}
 """.format(paramchars = paramchars, paramvals = paramvals, **self.__dict__)
@@ -347,18 +352,20 @@ Py_{shortname}_del  (Py_{shortname} * self, PyObject * unused)
         for input_param in self.do_inputs:
             if input_param['type'] == 'fmat_t *':
                 out += """
-    free(self->{0[name]}.data);""".format(input_param)
+  free(self->{0[name]}.data);""".format(input_param)
         for o in self.outputs:
             name = o['name']
             del_out = delfromtype_fn[o['type']]
             out += """
-    {del_out}(self->{name});""".format(del_out = del_out, name = name)
+  if (self->{name}) {{
+    {del_out}(self->{name});
+  }}""".format(del_out = del_out, name = name)
         del_fn = get_name(self.del_proto)
         out += """
-    if (self->o) {{
-        {del_fn}(self->o);
-    }}
-    Py_TYPE(self)->tp_free((PyObject *) self);
+  if (self->o) {{
+    {del_fn}(self->o);
+  }}
+  Py_TYPE(self)->tp_free((PyObject *) self);
 }}
 """.format(del_fn = del_fn)
         return out
@@ -373,6 +380,8 @@ Py_{shortname}_do  (Py_{shortname} * self, PyObject * args)
         output_params = self.do_outputs
         #print input_params
         #print output_params
+        out += """
+    PyObject *outputs;"""
         for input_param in input_params:
             out += """
     PyObject *py_{0};""".format(input_param['name'])
@@ -415,12 +424,25 @@ Py_{shortname}_do  (Py_{shortname} * self, PyObject * args)
         out += """
 
     {do_fn}(self->o, {inputs}, {c_outputs});
-
-    return {outputs};
-}}
 """.format(
         do_fn = do_fn,
-        inputs = inputs, outputs = outputs, c_outputs = c_outputs,
+        inputs = inputs, c_outputs = c_outputs,
+        )
+        if len(self.do_outputs) > 1:
+            out += """
+    outputs = PyTuple_New({:d});""".format(len(self.do_outputs))
+            for i, p in enumerate(self.do_outputs):
+                out += """
+    PyTuple_SetItem( outputs, {i}, self->{p[name]});""".format(i = i, p = p)
+        else:
+            out += """
+    outputs = self->{p[name]};""".format(p = self.do_outputs[0])
+        out += """
+
+    return outputs;
+}}
+""".format(
+        outputs = outputs,
         )
         return out
 
