@@ -1,4 +1,4 @@
-#include <aubio.h>
+#include "aubio.h"
 #include "utils_tests.h"
 
 int main (void)
